@@ -690,6 +690,9 @@ thunar_details_view_button_press_event (GtkTreeView       *tree_view,
       && !gtk_tree_view_get_path_at_pos (tree_view, event->x, event->y, &path, &column, NULL, NULL))
       gtk_tree_selection_unselect_all (selection);
 
+  /* make sure that rubber banding is enabled */
+  gtk_tree_view_set_rubber_banding (tree_view, TRUE);
+
   /* if the user clicked on a row with the left button */
   if (path != NULL && event->type == GDK_BUTTON_PRESS && event->button == 1)
     {
